@@ -8,6 +8,7 @@ import click
 import click_completion
 
 from griffon import (
+    check_envvars,
     config_logging,
     get_config_option,
     list_config_sections,
@@ -134,6 +135,8 @@ def cli(
 ):
     """Red Hat product security CLI"""
 
+    check_envvars()
+
     if ctx.invoked_subcommand is None:
         click.echo(ctx.parent.get_help())
 
