@@ -32,7 +32,7 @@ from component_registry_bindings.bindings.python_client.models import (
     SoftwareBuild,
 )
 
-from griffon import CORGI_API_URL, CorgiService, progress_bar
+from griffon import CORGI_SERVER_URL, CorgiService, progress_bar
 from griffon.autocomplete import (
     get_component_purls,
     get_product_stream_names,
@@ -43,6 +43,7 @@ from griffon.commands.entities.helpers import (
     multivalue_params_to_csv,
     query_params_options,
 )
+from griffon.exceptions import GriffonException
 from griffon.output import console, cprint
 
 logger = logging.getLogger("griffon")
@@ -59,7 +60,7 @@ def corgi_grp(ctx):
 # COMPONENTS
 
 
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/components")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/components")
 @click.pass_context
 def components(ctx):
     """Corgi Components."""
@@ -82,7 +83,7 @@ def components(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_components(ctx, strict_name_search, component_name, **params):
     is_params_empty = [False for v in params.values() if v]
     if not component_name and not is_params_empty:
@@ -116,7 +117,7 @@ def list_components(ctx, strict_name_search, component_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component(ctx, component_id, purl, **params):
     is_params_empty = [False for v in params.values() if v]
     if not component_id and not purl and not is_params_empty:
@@ -164,7 +165,7 @@ def get_component(ctx, component_id, purl, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_summary(ctx, component_name, strict_name_search, **params):
     """Get Component summary."""
     is_params_empty = [False for v in params.values() if v]
@@ -198,7 +199,7 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
         for ps in component.product_streams:
             product_streams.append(ps["name"])
     data = {
-        "link": f"{CORGI_API_URL}/api/v1/components?name={component_name}",
+        "link": f"{CORGI_SERVER_URL}/api/v1/components?name={component_name}",
         "type": component_type,
         "name": component_name,
         "tags": sorted(list(set(tags))),
@@ -225,7 +226,7 @@ def get_component_summary(ctx, component_name, strict_name_search, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_provides(ctx, component_uuid, purl, **params):
     """Retrieve all Components provided by a Component."""
     is_params_empty = [False for v in params.values() if v]
@@ -263,7 +264,7 @@ def get_component_provides(ctx, component_uuid, purl, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_sources(ctx, component_uuid, purl, **params):
     """Retrieve all Components that contain Component."""
     is_params_empty = [False for v in params.values() if v]
@@ -303,7 +304,7 @@ def get_component_sources(ctx, component_uuid, purl, **params):
     help="Generate spdx manifest (json).",
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_manifest(ctx, component_uuid, purl, spdx_json_format):
     """Retrieve Component manifest."""
     if not component_uuid and not purl:
@@ -335,7 +336,7 @@ def get_component_manifest(ctx, component_uuid, purl, spdx_json_format):
     help="Display purl.",
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_component_tree(ctx, component_uuid, nvr, purl, show_purl):
     """Retrieve Component dependency tree."""
     if not component_uuid and not purl and not nvr:
@@ -352,14 +353,14 @@ def get_component_tree(ctx, component_uuid, nvr, purl, show_purl):
         component_uuid = c.results[0].uuid
     c = session.components.retrieve(component_uuid, include_fields="uuid,nvr,arch")
     if c.arch == "src" or c.arch == "noarch":
-        data = requests.get(f"{CORGI_API_URL}/api/v1/components/{component_uuid}/taxonomy")
+        data = requests.get(f"{CORGI_SERVER_URL}/api/v1/components/{component_uuid}/taxonomy")
         return cprint(data.json(), ctx=ctx)
     else:
         logger.info(f"{c.nvr},{c.arch} not a root component.")
 
 
 # PRODUCT STREAM
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/product_streams")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product_streams")
 @click.pass_context
 def product_streams(ctx):
     pass
@@ -380,7 +381,7 @@ def product_streams(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_product_streams(ctx, product_stream_name, **params):
     """Retrieve a list of Product Streams."""
     is_params_empty = [False for v in params.values() if v]
@@ -417,7 +418,7 @@ def list_product_streams(ctx, product_stream_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_stream(ctx, product_stream_name, inactive, ofuri, **params):
     """Retrieve Product Stream."""
     is_params_empty = [False for v in params.values() if v]
@@ -449,7 +450,8 @@ def get_product_stream(ctx, product_stream_name, inactive, ofuri, **params):
     },
 )
 @click.pass_context
-def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
+@progress_bar(is_updatable=True)
+def get_product_stream_components(ctx, product_stream_name, ofuri, operation_status, **params):
     """Retrieve Product Stream latest Components."""
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
@@ -465,6 +467,8 @@ def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
         params["ofuri"] = ps["ofuri"]
     if ofuri:
         params["ofuri"] = ofuri
+
+    operation_status.stop()
     ctx.invoke(list_components, **params)
 
 
@@ -484,7 +488,7 @@ def get_product_stream_components(ctx, product_stream_name, ofuri, **params):
     help="Generate spdx manifest (json).",
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_stream_manifest(ctx, product_stream_name, ofuri, spdx_json_format):
     """Retrieve Product Stream manifest."""
     if not ofuri and not product_stream_name:
@@ -512,7 +516,7 @@ def get_product_stream_manifest(ctx, product_stream_name, ofuri, spdx_json_forma
 # BUILDS
 
 
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/builds")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/builds")
 @click.pass_context
 def builds(ctx):
     pass
@@ -528,7 +532,7 @@ def builds(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_software_builds(ctx, software_build_name, **params):
     """Retrieve a list of Software Builds."""
     session = CorgiService.create_session()
@@ -555,7 +559,7 @@ def list_software_builds(ctx, software_build_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_software_build(ctx, software_build_name, **params):
     """Retrieve SoftwareBuild."""
     is_params_empty = [False for v in params.values() if v]
@@ -572,7 +576,7 @@ def get_software_build(ctx, software_build_name, **params):
 # Products
 
 
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/products")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/products")
 @click.pass_context
 def products(ctx):
     pass
@@ -588,7 +592,7 @@ def products(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_products(ctx, product_name, **params):
     """Retrieve a list of Software Builds."""
     session = CorgiService.create_session()
@@ -616,7 +620,7 @@ def list_products(ctx, product_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product(ctx, product_name, ofuri, **params):
     """Retrieve Product."""
     is_params_empty = [False for v in params.values() if v]
@@ -633,7 +637,7 @@ def get_product(ctx, product_name, ofuri, **params):
 
 
 # PRODUCT VERSION
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/product-versions")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product-versions")
 @click.pass_context
 def product_versions(ctx):
     pass
@@ -649,7 +653,7 @@ def product_versions(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_product_versions(ctx, product_version_name, **params):
     """Retrieve a list of Product Versions."""
     session = CorgiService.create_session()
@@ -678,7 +682,7 @@ def list_product_versions(ctx, product_version_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_version(ctx, product_version_name, ofuri, **params):
     """Retrieve ProductVersion."""
     is_params_empty = [False for v in params.values() if v]
@@ -695,7 +699,7 @@ def get_product_version(ctx, product_version_name, ofuri, **params):
 
 
 # PRODUCT VARIANT
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/product-variants")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/product-variants")
 @click.pass_context
 def product_variants(ctx):
     pass
@@ -711,7 +715,7 @@ def product_variants(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_product_variants(ctx, product_variant_name, **params):
     """Retrieve a list of Product Variants."""
     session = CorgiService.create_session()
@@ -740,7 +744,7 @@ def list_product_variants(ctx, product_variant_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_product_variant(ctx, product_variant_name, ofuri, **params):
     """Retrieve ProductVariant."""
     is_params_empty = [False for v in params.values() if v]
@@ -757,7 +761,7 @@ def get_product_variant(ctx, product_variant_name, ofuri, **params):
 
 
 # CHANNEL
-@corgi_grp.group(help=f"{CORGI_API_URL}/api/v1/channels")
+@corgi_grp.group(help=f"{CORGI_SERVER_URL}/api/v1/channels")
 @click.pass_context
 def channels(ctx):
     pass
@@ -773,7 +777,7 @@ def channels(ctx):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def list_channels(ctx, channel_name, **params):
     """Retrieve a list of Channels."""
     session = CorgiService.create_session()
@@ -801,7 +805,7 @@ def list_channels(ctx, channel_name, **params):
     },
 )
 @click.pass_context
-@progress_bar
+@progress_bar()
 def get_channel(ctx, channel_name, ofuri, **params):
     """Retrieve ProductVariant."""
     is_params_empty = [False for v in params.values() if v]
@@ -835,26 +839,26 @@ def corgi_status(ctx):
 
 @manage_grp.command(name="health")
 @click.pass_context
-@progress_bar
+@progress_bar()
 def corgi_health(ctx):
     try:
         session = CorgiService.create_session()
         status = session.status()["status"]
         if status == "ok":
-            console.log(f"{CORGI_API_URL} is operational")
+            console.log(f"{CORGI_SERVER_URL} is operational")
         else:
-            console.log(f"{CORGI_API_URL} is NOT operational")
+            console.log(f"{CORGI_SERVER_URL} is NOT operational")
             exit(1)
     except:  # noqa
-        console.log(f"{CORGI_API_URL} is NOT operational")
-        raise click.ClickException("Component registry health check failed.")
+        console.log(f"{CORGI_SERVER_URL} is NOT operational")
+        raise GriffonException("Component registry health check failed.")
 
 
 @manage_grp.command(name="data")
 def corgi_data():
-    click.launch(f"{CORGI_API_URL}/data")
+    click.launch(f"{CORGI_SERVER_URL}/data")
 
 
 @manage_grp.command(name="api_doc")
 def corgi_api_docs():
-    click.launch(f"{CORGI_API_URL}/api/v1/schema/docs")
+    click.launch(f"{CORGI_SERVER_URL}/api/v1/schema/docs")
